@@ -49,10 +49,6 @@ function prepare_images {
         GATE_IMAGES+=",^masakari-,^hacluster-"
     fi
 
-    if [[ $SCENARIO == "swift" ]]; then
-        GATE_IMAGES+=",^swift"
-    fi
-
     if [[ $SCENARIO == "ovn" ]]; then
         GATE_IMAGES+=",^redis,^octavia,^ovn"
     fi
@@ -69,6 +65,10 @@ function prepare_images {
         GATE_IMAGES="^cron,^fluentd,^grafana,^haproxy,^proxysql,^keepalived,^kolla-toolbox,^mariadb,^memcached,^opensearch,^prometheus,^rabbitmq"
     fi
 
+    if [[ $SCENARIO == "ipv6" ]]; then
+        GATE_IMAGES+=",^prometheus"
+    fi
+
     if [[ $SCENARIO == "venus" ]]; then
         GATE_IMAGES="^cron,^opensearch,^fluentd,^haproxy,^proxysql,^keepalived,^keystone,^kolla-toolbox,^mariadb,^memcached,^rabbitmq,^venus"
     fi
@@ -96,7 +96,7 @@ EOF
     sudo mkdir -p /tmp/logs/build
     sudo mkdir -p /opt/kolla_registry
 
-    sudo $CONTAINER_ENGINE run -d --net=host -e REGISTRY_HTTP_ADDR=0.0.0.0:4000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry quay.io/opendevmirror/registry:2
+    sudo $CONTAINER_ENGINE run -d --net=host -e REGISTRY_HTTP_ADDR=0.0.0.0:4000 --restart=always -v /opt/kolla_registry/:/var/lib/registry --name registry quay.io/libpod/registry:2.8.2
 
 
     python3 -m venv ~/kolla-venv
