@@ -16,7 +16,7 @@ function check_certificate_expiry {
 }
 
 function register_amphora_image {
-    amphora_url=https://tarballs.opendev.org/openstack/octavia/test-images/test-only-amphora-x64-haproxy-ubuntu-focal.qcow2
+    amphora_url=https://tarballs.opendev.org/openstack/octavia/test-images/test-only-amphora-x64-haproxy-ubuntu-jammy.qcow2
     curl -o amphora.qcow2 $amphora_url
     (. /etc/kolla/octavia-openrc.sh && openstack image create amphora-x64-haproxy --file amphora.qcow2  --tag amphora --disk-format qcow2 --property hw_architecture='x86_64' --property hw_rng_model=virtio)
 }
@@ -30,7 +30,7 @@ function test_octavia {
     # Create a Loadblanacer
     openstack loadbalancer create --name lb --vip-subnet-id demo-subnet --wait
     # Create a server to act as a backend.
-    openstack server create --wait --image cirros --flavor c1.tiny --key-name mykey --network demo-net lb_member --wait
+    openstack server create --wait --image cirros --flavor m1.tiny --key-name mykey --network demo-net lb_member --wait
     member_fip=$(openstack floating ip create public1 -f value -c floating_ip_address)
     openstack server add floating ip lb_member ${member_fip}
     member_ip=$(openstack floating ip show ${member_fip} -f value -c fixed_ip_address)
@@ -132,7 +132,7 @@ function test_internal_dns_integration {
         SERVER_NAME="my_vm"
         SERVER_NAME_SANITIZED=$(echo ${SERVER_NAME} | sed -e 's/_/-/g')
 
-        openstack server create --image cirros --flavor c1.tiny --network dns-test-network ${SERVER_NAME}
+        openstack server create --image cirros --flavor m1.tiny --network dns-test-network ${SERVER_NAME}
 
         SERVER_ID=$(openstack server show ${SERVER_NAME} -f value -c id)
         attempt=0
